<?php

namespace App\Containers\Documentation\Actions;

use App\Containers\Documentation\Tasks\GenerateAPIDocsTask;
use App\Containers\Documentation\Tasks\GetDocsTypesTask;
use App\Containers\Documentation\Tasks\RenderTemplatesTask;
use App\Ship\Parents\Actions\Action;

/**
 * Class GenerateDocumentationAction.
 *
 * @author Mahmoud Zalt <mahmoud@zalt.me>
 */
class GenerateDocumentationAction extends Action
{

    /**
     * @param $console
     */
    public function run($console)
    {
        // parse the markdown file.
        $this->call(RenderTemplatesTask::class);

        // get docs types that needs to be generated by the user base on his configs.
        $types = $this->call(GetDocsTypesTask::class);

        $console->info("Generating API Documentations for (" . implode(' & ', $types) . ")\n");

        $documentationUrls = [];

        // for each type, generate docs.
        foreach ($types as $type) {
            $documentationUrls[] = $this->call(GenerateAPIDocsTask::class, [$type, $console]);
        }

        $console->info("Done! You can access your API Docs at: \n" . implode("\n", $documentationUrls));
    }

}
