---
title: "Installation"
category: "Getting Started"
order: 4
---



* [A) Development Environment Setup](#Development-Environment)
	* [Option 1: Using Docker and Laradock](#Dev-Env-Opt-A)
	* [Option 2: Using Vagrant and Homestead](#Dev-Env-Opt-B)
	* [Option 3: using something else!](#Development-Environment)
* [B) Application Setup](#App)
	* [1) Code Setup](#Code-Setup)
		* [Option 1: Automatically via Composer](#App-Composer)
		* [Option 2: Manually](#App-Git)
	* [2) Database Setup](#Setup-Database)
	* [3) OAuth Setup](#Prepare-OAuth)
	* [4) Documentation Setup](#Documentation)
	* [5) Testing Setup](#Testing)
* [C) Play](#Play)


 
 



<a name="Development-Environment"></a>
## A) Development Environment Setup

You can run **apiato** on your favorite environment. Below you'll see how you can run it on top of [Vagrant](https://www.vagrantup.com/) (using [Laravel Homestead](https://laravel.com/docs/master/homestead)) or [Docker](https://www.docker.com/) (using [Laradock](https://github.com/Laradock/laradock)). 
We'll see how to use both tools and you can pick one, or you can use other options like [Larvel Valet](https://laravel.com/docs/valet), [Laragon](https://laragon.org/) or even run it directly on your machine.

<a name="Dev-Env-Opt-A"></a>
### A.1) Using Docker (with Laradock)

**Laradock** is a Docker PHP development environment. It facilitate running PHP Apps on Docker.

1) Install [Laradock](https://github.com/LaraDock/laradock#installation).

2) Navigate into the `laradock` directory:

```shell
cd laradock
```
This directory contains a `docker-compose.yml` file. (From the LaraDock project).

3) Run the Docker containers:

```shell
docker-compose up -d nginx mysql redis beanstalkd
```

4) Make sure you are setting the `Docker IP` as `Host` for the `DB` and `Redis`  in your `.env` file.

5) Add the domain to the Hosts file:

5.1) Open the hosts file on your local machine `/etc/hosts`.

*We'll be using `apiato.dev` as local domain (you can change it if you want).*

5.2) Map the domain and its subdomains to 127.0.0.1:

```text
127.0.0.1  apiato.dev
127.0.0.1  api.apiato.dev
127.0.0.1  admin.apiato.dev
```


<a name="Dev-Env-Opt-A"></a>
### A.2) Using Vagrant (with Laravel Homestead)

1) Configure Homestead:

1.1) Open the Homestead config file:

```shell
homestead edit
```

1.2) Map the `api.apiato.dev` domain to the project public directory - Example:

```text
sites:
	- map: api.apiato.dev
  	  to: /{full-path-to}/apiato/public
```

1.3) You can also map other domains like `apiato.dev` and `admin.apiato.dev` to the user web apps:

```text
	- map: apiato.dev
  	  to: /{full-path-to}/apiato/clients/web/user
	- map: admin.apiato.dev
  	  to: /{full-path-to}/apiato/clients/web/admin
```

2) Add the domain to the Hosts file:

2.1) Open the hosts file on your local machine `/etc/hosts`.

*We'll be using `apiato.dev` as local domain (you can change it if you want).*

2.2) Map the domain and its subdomains to the Vagrant IP Address:

```text
192.168.10.10   apiato.dev
192.168.10.10   api.apiato.dev
192.168.10.10   admin.apiato.dev
```

2.3) Run the Virtual Machine:

```shell
homestead up --provision
```

*If you see `No input file specified` on the subdomains! try running this command `homestead halt && homestead up --provision`.*





<a name="App"></a>

## B) Application Setup

**apiato** can be installed automatically with Composer (recommended) or manually (with Git or direct download):


<a name="Code-Setup"></a>
### 1) Code Setup


<a name="App-Composer"></a>
#### 1.A) Automatically via Composer

1) Clone the repo, install dependencies and setup the project:

```shell
composer create-project apiato/apiato api
```

2) Edit your `.env` variables to match with your environment (Set Database credentials, App URL, ...).


<a name="App-Git"></a>
#### 1.B) Manually

You can download the Code directly from the repository as `.ZIP` file or clone the repository using `Git` (recommended):


1) Clone the repository using `Git`:

 ```shell
git clone https://github.com/apiato/apiato.git
 ```

2) Install all dependency packages (including Containers dependencies):

```shell
composer install
```

3) Create `.env` file and copy the content of `.env.example` inside it.

```shell
cp .env.example .env
```

*Check all the variables and edit whatever you want.*

4) Generate a random key `APP_KEY`

```shell
php artisan key:generate
```

5) delete the `.git` folder from the root directory and initialize your own with `git init`.




<a name="Setup-Database"></a>
### 2) Database Setup

1) Migrate the Database:

b. Run the migration artisan command:

```shell
php artisan migrate
```

2) Seed the database with the artisan command:

```shell
php artisan db:seed
```

**NOTE:** if you are using Laradock, you need to run those commands from the `workspace` Container, you can enter that container by running `docker-compose exec workspace bash` from the Laradock folder.


<a name="Prepare-OAuth"></a>
### 3) OAuth 2.0 Setup 


1) Create encryption keys to generate secure access tokens and create "personal access" and "password grant" clients which will be used to generate access tokens:

```shell
php artisan passport:install
```


<a name="Documentation"></a>
### 4) Documentation Setup

If you are planning to use ApiDoc JS then proceed with this setup, else skip this and use whatever you prefer:

1) Install [ApiDocJs](http://apidocjs.com/) using NPM or any other way:
```shell
npm install
```

2) run `php artisan apiato:documentation`

##### Visit [API Docs Generator](http://apiato.io/C.features/api-docs-generator/) for more details.



<a name="Testing"></a>
### 5) Testing Setup

1) Open `phpunit.xml` and make sure the environments are correct for your domain.
 
2) run the tests

```shell
phpunit
```





<a name="Play"></a>
## C) Play

Now let's see it in action

1. Open your web browser and visit: 

- `http://apiato.dev` You should see an HTML page, with `apiato` in the middle.
- `http://api.apiato.dev/` You should see a JSON response with message: `Welcome to apiato.`, you can also to go `http://api.apiato.dev/v1` and see a welcome response to your API version 1 landing page
- `http://admin.apiato.dev` You should see an HTML Login page.


2) Make some HTTP calls to the API:

*To make the calls you can use [Postman](https://www.getpostman.com/), [HTTPIE](https://github.com/jkbrzt/httpie) or any other tool you prefer.*

Let's test the (user registration) endpoint `http://api.apiato.dev/v1/register ` with **cURL**:

```shell
curl -X POST -H "Accept: application/json" -H "Cache-Control: no-cache" -F "email=mahmoud@zalt.me" -F "password=so-secret" -F "name=Mahmoud Zalt" "http://api.apiato.dev/v1/register"
```

You should get response similar to this:

```json
Access-Control-Allow-Origin → ...
Cache-Control → ...
Connection → keep-alive
Content-Language → en
Content-Type → application/json
Date → Wed, 11 Apr 2000 22:55:88 GMT
Server → nginx
Transfer-Encoding → chunked
Vary → Origin
X-Powered-By → PHP/7.7.7
X-RateLimit-Limit → 30
X-RateLimit-Remaining → 29

{
  "data": {
    "object": "User",
    "id": 77,
    "name": "Mahmoud Zalt",
    "email": "apiato@mail.com",
    "confirmed": null,
    "nickname": "Mega",
    "gender": "male",
    "birth": null,
    "social_auth_provider": null,
    "social_id": null,
    "social_avatar": {
      "avatar": null,
      "original": null
    },
    "created_at": {
      "date": "2017-04-05 16:17:26.000000",
      "timezone_type": 3,
      "timezone": "UTC"
    },
    "updated_at": {
      "date": "2017-04-05 16:17:26.000000",
      "timezone_type": 3,
      "timezone": "UTC"
    },
    "roles": {
      "data": []
    }
  }
}
```


